AiqiError

Enum AiqiError 

#[non_exhaustive]
pub enum AiqiError {
Show 19 variants ReturnHorizonZero, ReturnBinsZero, AugmentationPeriodTooShort { augmentation_period: usize, return_horizon: usize, }, InvalidDiscountGamma { value: f64, }, InvalidBaselineExploration { value: f64, }, RewardEncoding(RewardEncodingError), InvalidRateBackend(InfotheoryError), UnsupportedRateBackend { reason: &'static str, }, Spec(SpecError), ControllerKindMismatch, Predictor(PredictorBuildError), ActionOutOfRange { action: Action, agent_actions: ActionAlphabet, }, ObservationStreamLengthMismatch { expected: usize, actual: usize, }, RewardOutOfRange { reward: Reward, min_reward: Reward, max_reward: Reward, }, ObservationValueOutOfRange { observation: PerceptVal, observation_bits: usize, maximum: PerceptVal, }, NegativeEncodedReward { reward: Reward, reward_offset: Reward, }, EncodedRewardTooLarge { shifted_reward: i128, reward_bits: usize, maximum_encoded: u128, }, HistoryIndexOutOfRange { global_step: usize, history_base_step: usize, total_steps_observed: usize, }, MissingReturnBin { step: usize, phase: usize, },
}
Error returned by AIQI configuration validation, construction, and transition ingestion.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ReturnHorizonZero

return_horizon was zero.



ReturnBinsZero

return_bins was zero.



AugmentationPeriodTooShort

The augmentation period was smaller than the return horizon.

Fields

augmentation_period: usize

The configured augmentation period.

return_horizon: usize

The configured return horizon.



InvalidDiscountGamma

The discount factor was outside (0, 1).

Fields

value: f64

The invalid discount factor value.



InvalidBaselineExploration

The baseline exploration probability was outside (0, 1].

Fields

value: f64

The invalid baseline exploration value.



RewardEncoding(RewardEncodingError)

The configured reward range is not representable.



InvalidRateBackend(InfotheoryError)

The configured rate backend failed validation.



UnsupportedRateBackend

The configured rate backend violates AIQI runtime requirements.

Fields

reason: &'static str

Human-readable explanation of why the backend is unsupported.



Spec(SpecError)

Planner-run spec compilation failed.



ControllerKindMismatch

The compiled planner-run controller kind was not discounted AIQI.



Predictor(PredictorBuildError)

Predictor construction failed.



ActionOutOfRange

An observed action was outside the configured action alphabet.

Fields

action: Action

The out-of-range action token.

agent_actions: ActionAlphabet

The configured action alphabet cardinality.



ObservationStreamLengthMismatch

The observation stream length did not match the configured interface.

Fields

expected: usize

Expected observation stream length.

actual: usize

Actual observation stream length.



RewardOutOfRange

An observed reward was outside the configured reward range.

Fields

reward: Reward

Out-of-range reward value.

min_reward: Reward

Minimum configured reward.

max_reward: Reward

Maximum configured reward.



ObservationValueOutOfRange

An observation value exceeded the configured observation bit width.

Fields

observation: PerceptVal

Out-of-range observation value.

observation_bits: usize

Configured observation bit width.

maximum: PerceptVal

Maximum representable observation value for observation_bits.



NegativeEncodedReward

A shifted observed reward became negative.

Fields

reward: Reward

Original reward value.

reward_offset: Reward

Configured reward offset.



EncodedRewardTooLarge

A shifted observed reward exceeded the configured reward bit capacity.

Fields

shifted_reward: i128

Shifted reward value after applying offset.

reward_bits: usize

Configured reward bit width.

maximum_encoded: u128

Maximum representable encoded reward for reward_bits.



HistoryIndexOutOfRange

A requested global step is no longer present in retained history.

Fields

global_step: usize

Requested global step index.

history_base_step: usize

First retained global step index.

total_steps_observed: usize

Last observed global step index.



MissingReturnBin

A phase-model update required a return bin that has not been computed.

Fields

step: usize

Global step whose return bin was missing.

phase: usize

Augmentation phase that required the return bin.